@@ -1,4 +1,3 @@
-## TODO: return clustering object instead of cluster$order
 ## TODO: provide examples for adjusting legend size / spacing
 
 #' @title Visual Summary of Hillslope Position
@@ -13,10 +12,14 @@
 #' 
 #' @param annotation.cex annotation label scaling factor
 #' 
-#' @return a \code{list} with the following elements:
+#' @param cols vector of colors
 #' 
-#' \item{fig}{lattice object (the figure)}
-#' \item{order}{ordering of soil series}
+#' 
+#' @return
+#' A `list` with the following elements:
+#'    * `fig`: lattice object (the figure)
+#'    * `order`: 1D ordering from `cluster::diana`
+#'    * `clust`: clustering object returned by `cluster::diana`
 #' 
 #' @details See the \href{http://ncss-tech.github.io/AQP/soilDB/soil-series-query-functions.html}{Soil Series Query Functions} tutorial for more information.
 #' 
@@ -43,7 +46,7 @@
 #' }
 #' }
 #' 
-vizHillslopePosition <- function(x, s = NULL, annotations = TRUE, annotation.cex = 0.75) {
+vizHillslopePosition <- function(x, s = NULL, annotations = TRUE, annotation.cex = 0.75, cols = c("#2B83BA", "#ABDDA4", "#FFFFBF", "#FDAE61", "#D7191C")) {
   
   # check for required packages
   if(!requireNamespace('dendextend', quietly=TRUE) | !requireNamespace('latticeExtra', quietly=TRUE))
@@ -74,10 +77,7 @@ vizHillslopePosition <- function(x, s = NULL, annotations = TRUE, annotation.cex
   names(x.long)[2] <- 'hillslope_position'
   
   # make some colors, and set style
-  cols <- rev(brewer.pal(5, 'Spectral'))
-  
-  ## alternate colors: http://www.fabiocrameri.ch/colourmaps.php
-  # cols <- rev(scico(5, palette='roma'))
+  # cols <- rev(brewer.pal(5, 'Spectral'))
   
   # setup plot styling
   tps <- list(superpose.polygon=list(col=cols, lwd=2, lend=2))
@@ -192,7 +192,8 @@ vizHillslopePosition <- function(x, s = NULL, annotations = TRUE, annotation.cex
   # embed styling
   pp <- update(pp, par.settings = tps)
   
-  # the figure and ordering are returned
-  return(list(fig = pp, order = x.d.hydro$order))
+  # figure, ordering, clustering object
+  res <- list(fig = pp, order = x.d.hydro$order, clust = x.d.hydro)
+  return(res)
 }
 
